==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/modules/SqlUtil/html/group__sql__cops.js <==
var group__sql__cops =
[
    [ "COP_APPEND", "group__sql__cops.html#ga8e4c9ab6d5ccd9ee6ec73c81620a9f16", null ],
    [ "COP_AS", "group__sql__cops.html#gac19d79651b31032968649f644ec2d3da", null ],
    [ "COP_AVG", "group__sql__cops.html#ga76347b9d5c1da37258c0f11c539c4e8b", null ],
    [ "COP_CAST", "group__sql__cops.html#gac46a6a06a7a10ec548593d456b33d724", null ],
    [ "COP_COALESCE", "group__sql__cops.html#ga0eeab3270467052722d9246f6b53728b", null ],
    [ "COP_COUNT", "group__sql__cops.html#ga5de78eaf0c2f9fea151ffad0ed6d80e9", null ],
    [ "COP_DISTINCT", "group__sql__cops.html#gae9c9491c6792fbb67aa998911c66792d", null ],
    [ "COP_DIVIDE", "group__sql__cops.html#ga2540867988567969c10c289ee1ba1d8a", null ],
    [ "COP_LOWER", "group__sql__cops.html#gab78b29922b77d26bfbe1eaab6bf9af42", null ],
    [ "COP_MAX", "group__sql__cops.html#ga045c1e1c6df03ff933c5e6c668d8d517", null ],
    [ "COP_MIN", "group__sql__cops.html#ga19ebc657a6a4311844a50763a93ce138", null ],
    [ "COP_MINUS", "group__sql__cops.html#gadce1c9a9f25e6534ba60944d9c2485ac", null ],
    [ "COP_MULTIPLY", "group__sql__cops.html#ga681d65ea16c65717eca1df77a4b59a4d", null ],
    [ "COP_OVER", "group__sql__cops.html#ga050e638c47cb995b048f2afff0126f5d", null ],
    [ "COP_PLUS", "group__sql__cops.html#ga7d249ab65b0c3af7039ca2c70993a86a", null ],
    [ "COP_PREPEND", "group__sql__cops.html#gab295bb9dc1ae58edc09037d74507e000", null ],
    [ "COP_SEQ", "group__sql__cops.html#ga89274586533cd4f4121d6d23f10606b9", null ],
    [ "COP_SEQ_CURRVAL", "group__sql__cops.html#ga054b41324be2d26f3d8c18af7a909c88", null ],
    [ "COP_SUBSTR", "group__sql__cops.html#ga86a7c99f89ffbb05bf46137c089066d9", null ],
    [ "COP_SUM", "group__sql__cops.html#gaf9002f8655aaa571632cda1901d80340", null ],
    [ "COP_UPPER", "group__sql__cops.html#gad732f7795128548587d13d42667781d5", null ],
    [ "COP_VALUE", "group__sql__cops.html#ga0bbff735e271b62495539bbc466e7145", null ],
    [ "COP_YEAR", "group__sql__cops.html#ga43d8ff458a4db58b45c79851d7b902bf", null ],
    [ "COP_YEAR_DAY", "group__sql__cops.html#gacebe3b0582761292a36b07787c6dbd5b", null ],
    [ "COP_YEAR_HOUR", "group__sql__cops.html#ga1faef2c3f9981ac91d94065484bfd2f7", null ],
    [ "COP_YEAR_MONTH", "group__sql__cops.html#gaa4f20d410a2e77e8051051b8e6eebc0c", null ],
    [ "DefaultCopMap", "group__sql__cops.html#gae497d7c4b1316f78ea93522f8b7cd554", null ]
];

==> qore-1.5.0.tar.bz2: qore-1.5.0/docs/modules/SqlUtil/html/group__sql__cops.js <==
var group__sql__cops =
[
    [ "COP_APPEND", "group__sql__cops.html#ga8e4c9ab6d5ccd9ee6ec73c81620a9f16", null ],
    [ "COP_AS", "group__sql__cops.html#gac19d79651b31032968649f644ec2d3da", null ],
    [ "COP_AVG", "group__sql__cops.html#ga76347b9d5c1da37258c0f11c539c4e8b", null ],
    [ "COP_CAST", "group__sql__cops.html#gac46a6a06a7a10ec548593d456b33d724", null ],
    [ "COP_COALESCE", "group__sql__cops.html#ga0eeab3270467052722d9246f6b53728b", null ],
    [ "COP_COUNT", "group__sql__cops.html#ga5de78eaf0c2f9fea151ffad0ed6d80e9", null ],
    [ "COP_CUME_DIST", "group__sql__cops.html#ga7f32fea87f927a6b9e9e0783d23ff8c6", null ],
    [ "COP_DENSE_RANK", "group__sql__cops.html#gad9786d8a66002858d866df71dbeb998d", null ],
    [ "COP_DISTINCT", "group__sql__cops.html#gae9c9491c6792fbb67aa998911c66792d", null ],
    [ "COP_DIVIDE", "group__sql__cops.html#ga2540867988567969c10c289ee1ba1d8a", null ],
    [ "COP_FIRST_VALUE", "group__sql__cops.html#gadf0c53ab2432a4e1dce94b2479c541a0", null ],
    [ "COP_LAST_VALUE", "group__sql__cops.html#gadeca258a21bb190ded96e75224ec92d1", null ],
    [ "COP_LENGTH", "group__sql__cops.html#ga05e47f0480bcbdc4e233a2fafcccb12e", null ],
    [ "COP_LOWER", "group__sql__cops.html#gab78b29922b77d26bfbe1eaab6bf9af42", null ],
    [ "COP_MAX", "group__sql__cops.html#ga045c1e1c6df03ff933c5e6c668d8d517", null ],
    [ "COP_MIN", "group__sql__cops.html#ga19ebc657a6a4311844a50763a93ce138", null ],
    [ "COP_MINUS", "group__sql__cops.html#gadce1c9a9f25e6534ba60944d9c2485ac", null ],
    [ "COP_MULTIPLY", "group__sql__cops.html#ga681d65ea16c65717eca1df77a4b59a4d", null ],
    [ "COP_NTILE", "group__sql__cops.html#ga9b573bf518c393bbf1f8acbd931408a3", null ],
    [ "COP_OVER", "group__sql__cops.html#ga050e638c47cb995b048f2afff0126f5d", null ],
    [ "COP_PERCENT_RANK", "group__sql__cops.html#ga992175a290f123f1623e71c29951db22", null ],
    [ "COP_PLUS", "group__sql__cops.html#ga7d249ab65b0c3af7039ca2c70993a86a", null ],
    [ "COP_PREPEND", "group__sql__cops.html#gab295bb9dc1ae58edc09037d74507e000", null ],
    [ "COP_RANK", "group__sql__cops.html#ga0914ff8c8f96844528a1740c1eac31a2", null ],
    [ "COP_ROW_NUMBER", "group__sql__cops.html#gac5ec1526d82e46d12f6f784d14843fff", null ],
    [ "COP_SEQ", "group__sql__cops.html#ga89274586533cd4f4121d6d23f10606b9", null ],
    [ "COP_SEQ_CURRVAL", "group__sql__cops.html#ga054b41324be2d26f3d8c18af7a909c88", null ],
    [ "COP_SUBSTR", "group__sql__cops.html#ga86a7c99f89ffbb05bf46137c089066d9", null ],
    [ "COP_SUM", "group__sql__cops.html#gaf9002f8655aaa571632cda1901d80340", null ],
    [ "COP_TRUNC_DATE", "group__sql__cops.html#gadc61c458d91603939c0278d1dde017cf", null ],
    [ "COP_UPPER", "group__sql__cops.html#gad732f7795128548587d13d42667781d5", null ],
    [ "COP_VALUE", "group__sql__cops.html#ga0bbff735e271b62495539bbc466e7145", null ],
    [ "COP_YEAR", "group__sql__cops.html#ga43d8ff458a4db58b45c79851d7b902bf", null ],
    [ "COP_YEAR_DAY", "group__sql__cops.html#gacebe3b0582761292a36b07787c6dbd5b", null ],
    [ "COP_YEAR_HOUR", "group__sql__cops.html#ga1faef2c3f9981ac91d94065484bfd2f7", null ],
    [ "COP_YEAR_MONTH", "group__sql__cops.html#gaa4f20d410a2e77e8051051b8e6eebc0c", null ],
    [ "DefaultCopMap", "group__sql__cops.html#gae497d7c4b1316f78ea93522f8b7cd554", null ]
];
